import numpy as np
from ladybug_geometry.geometry3d import Point3D, Vector3D


def calculate_no_of_panels(system_size, panel_peak_power):
    """
    Calculate the number of panels needed for a given system size and panel peak power.

    Args:
        system_size (float): The total system size in kWp.
        panel_peak_power (float): The peak power of a single panel in Wp.

    Returns:
        int: The number of panels needed.
    """
    panel_peak_power_kWp = panel_peak_power / 1000  # Convert Wp to kWp
    no_of_panels = np.ceil(system_size / panel_peak_power_kWp)

    return no_of_panels
